bfa_lbc_ls: Linear Function Bias-Corrected Estimators for BAR(p); p=1,2,...,6
Description
This function performs bias correction on the least squares estimators of the
autoregressive coefficients in a BAR(p) model based on the assumption that
the bias of the least squares estimator is approximately linear as a function
of the parameter as described in Elbayoumi and Mostafa (2020).
Usage
bfa_lbc_ls(z, p)
Value
coef_lbc
linear-bias-function-based bias-corrected least
squares estimates of the autoregressive coefficients
Arguments
z
a numeric vector containing the tree data
p
an integer determining the order of bifurcating autoregressive model
to be fit to the data
References
Elbayoumi, T. M. & Mostafa, S. A. (2020). On the estimation bias
in bifurcating autoregressive models. Stat, 1-16.