Learn R Programming

bifurcatingr (version 2.1.0)

bfa_perc_ci: Percentile Bootstrap Confidence Interval Function

Description

This function calculates the percentile bootstrap CI for the least squares estimator of the bifurcating autoregressive model.

Usage

bfa_perc_ci(a1_ls_star, conf_level = 0.95)

Value

A numeric vector representing the lower and upper limits of the confidence interval.

Arguments

a1_ls_star

A numeric vector representing B replicates of the least squares estimator.

conf_level

A numeric value representing the confidence level. Defaults to 0.95.

Examples

Run this code
a1_ls_star <- c(rnorm(100,0.7,0.05))
bfa_perc_ci(a1_ls_star, conf_level= 0.95)

Run the code above in your browser using DataLab