Learn R Programming

bifurcatingr (version 2.1.0)

emt6: Mean Lifetimes (in tenths of hours) of EMT6 (BALB/c mouse mammary tumor) cells.

Description

A real cell lineage dataset taken from Staudte et al. (1984). The values represent the mean lifetimes in tenths of hours obtained from averaging observations from 41 bifurcating trees. The averaging of observations and the tree are made by Elbayoumi and Mostafa (2023).

Usage

emt6

Arguments

Format

A data frame with 63 rows and 1 variable:

mean.lifetime

EMT6 cells lifetime, in tenths of hours