powered by
This function calculates the percentile bootstrap CI for the least squares estimator of the bifurcating autoregressive model.
bfa_perc_ci(a1_ls_star, conf_level = 0.95)
A numeric vector representing the lower and upper limits of the confidence interval.
A numeric vector representing B replicates of the least squares estimator.
A numeric value representing the confidence level. Defaults to 0.95.
a1_ls_star <- c(rnorm(100,0.7,0.05)) bfa_perc_ci(a1_ls_star, conf_level= 0.95)
Run the code above in your browser using DataLab